@@ -19,10 +19,9 @@ use base 'PDF::Builder::Basic::PDF::Objind';
 
 use strict;
 use warnings;
-#no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '3.023'; # VERSION
-our $LAST_UPDATE = '3.022'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
 
 our $mincache = 16 * 1024 * 1024;
 
@@ -61,10 +60,21 @@ source PDF the stream starts.
 
 =head1 METHODS
 
+=head2 new
+
+    $d = PDF::Builder::Basic::PDF->new()
+
+=over
+
+Creates a new instance of a dictionary. The usual practice is to call 
+C<PDFDict()> instead.
+
+=back
+
 =cut
 
 sub new {
-    my ($class) = @_;
+    my $class = shift();  # have @_ used, later
 
     $class = ref($class) if ref($class);
 
@@ -73,10 +83,16 @@ sub new {
     return $self;
 }
 
-=head2 $type = $d->type($type)
+=head2 type
+
+    $type = $d->type($type)
+
+=over
 
 Get/Set the standard Type key. It can be passed, and will return, a text value rather than a Name object.
 
+=back
+
 =cut
 
 sub type {
@@ -89,10 +105,16 @@ sub type {
     return $self->{'Type'}->val();
 }
 
-=head2 @filters = $d->filter(@filters)
+=head2 filter
+
+    @filters = $d->filter(@filters)
+
+=over
 
 Get/Set one or more filters being used by the optional stream attached to the dictionary.
 
+=back
+
 =cut
 
 sub filter {
@@ -112,10 +134,14 @@ sub filter {
     return $self->{'Filter'};
 }
 
-# Undocumented alias, which may be removed in a future release
+# Undocumented alias, which may be removed in a future release TBD
 sub filters { return filter(@_); }
 
-=head2 $d->outobjdeep($fh, $pdf)
+=head2 outobjdeep
+
+    $d->outobjdeep($fh, $pdf)
+
+=over
 
 Outputs the contents of the dictionary to a PDF file. This is a recursive call.
 
@@ -123,6 +149,8 @@ It also outputs a stream if the dictionary has a stream element. If this occurs
 then this method will calculate the length of the stream and insert it into the
 stream's dictionary.
 
+=back
+
 =cut
 
 sub outobjdeep {
@@ -233,7 +261,11 @@ sub outobjdeep {
     return;
 }
 
-=head2 $d->read_stream($force_memory)
+=head2 read_stream
+
+    $d->read_stream($force_memory)
+
+=over
 
 Reads in a stream from a PDF file. If the stream is greater than
 C<PDF::Dict::mincache> (defaults to 32768) bytes to be stored, then
@@ -242,6 +274,8 @@ file as a data cache. If $force_memory is set, this caching will not
 occur and the data will all be stored in the $self->{' stream'}
 variable.
 
+=back
+
 =cut
 
 sub read_stream {
@@ -315,10 +349,16 @@ sub read_stream {
     return $self;
 }
 
-=head2 $d->val()
+=head2 val
+
+    $d->val()
+
+=over
 
 Returns the dictionary, which is itself.
 
+=back
+
 =cut
 
 sub val {
