@@ -20,8 +20,8 @@ use base 'PDF::Builder::Basic::PDF::String';
 use strict;
 use warnings;
 
-our $VERSION = '3.023'; # VERSION
-our $LAST_UPDATE = '3.022'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
 
 =head1 NAME
 
@@ -30,12 +30,18 @@ and stores PDF names (things beginning with /)
 
 =head1 METHODS
 
-=head2 $n = PDF::Builder::Basic::PDF::Name->from_pdf($string)
+=head2 from_pdf
+
+    $n = PDF::Builder::Basic::PDF::Name->from_pdf($string)
+
+=over
 
 Creates a new string object (not a full object yet) from a given
-string.  The string is parsed according to input criteria with
+string. The string is parsed according to input criteria with
 escaping working, particular to Names.
 
+=back
+
 =cut
 
 sub from_pdf {
@@ -47,11 +53,17 @@ sub from_pdf {
     return $self;
 }
 
-=head2 $n->convert($string, $pdf)
+=head2 convert
+
+    $n->convert($string, $pdf)
+
+=over
 
 Converts a name into a string by removing the / and converting any hex
 munging.
 
+=back
+
 =cut
 
 sub convert {
@@ -61,11 +73,17 @@ sub convert {
     return $string;
 }
 
-=head2 $s->as_pdf($pdf)
+=head2 as_pdf
+
+    $s->as_pdf($pdf)
+
+=over
 
 Returns a name formatted as PDF. C<$pdf> is optional but should be the
 PDF File object for which the name is intended if supplied.
 
+=back
+
 =cut
 
 sub as_pdf {
@@ -82,11 +100,17 @@ sub as_pdf {
 # spaces were implicitly allowed in names as well but it would be best
 # to ignore that (PDF 1.3, section H.3.2.4.3).
 
-=head2 PDF::Builder::Basic::PDF::Name->string_to_name($string, $pdf)
+=head2 string_to_name
+
+    PDF::Builder::Basic::PDF::Name->string_to_name($string, $pdf)
+
+=over
 
 Suitably encode the string C<$string> for output in the File object C<$pdf>
 (the exact format may depend on the version of $pdf).
 
+=back
+
 =cut
 
 sub string_to_name {
@@ -100,12 +124,18 @@ sub string_to_name {
     return $string;
 }
 
-=head2 PDF::Builder::Basic::PDF::Name->name_to_string($string, $pdf)
+=head2 name_to_string
+
+    PDF::Builder::Basic::PDF::Name->name_to_string($string, $pdf)
+
+=over
 
 Suitably decode the string C<$string> as read from the File object C<$pdf>
 (the exact decoding may depend on the version of $pdf).  Principally,
 undo the hex encoding for PDF versions > 1.1.
 
+=back
+
 =cut
 
 sub name_to_string {
