@@ -5,8 +5,8 @@ use base 'PDF::Builder::Basic::PDF::Dict';
 use strict;
 use warnings;
 
-our $VERSION = '3.025'; # VERSION
-our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
 
 use Carp qw(croak);
 use PDF::Builder::Basic::PDF::Utils;
@@ -28,12 +28,16 @@ PDF::Builder::Outline - Manage PDF outlines (a.k.a. I<bookmarks>)
 
 =head1 METHODS
 
+=head2 new
+
+    $outline = PDF::Builder::Outline->new($api, $parent, $prev)
+
 =over
 
-=item $outline = PDF::Builder::Outline->new($api, $parent, $prev)
-
 Returns a new outline object (called from $outlines->outline()).
 
+=back
+
 =cut
 
 sub new {
@@ -50,16 +54,18 @@ sub new {
     return $self;
 }
 
-=back
-
 =head2 Examine the Outline Tree
 
+=head3 has_children
+
+    $boolean = $outline->has_children()
+
 =over
 
-=item $boolean = $outline->has_children()
-
 Return true if the current outline item has children (child items).
 
+=back
+
 =cut
 
 sub has_children {
@@ -74,11 +80,17 @@ sub has_children {
     return;
 }
 
-=item $integer = $outline->count()
+=head3 count
+
+    $integer = $outline->count()
+
+=over
 
 Return the number of descendants that are visible when the current outline item
 is open (expanded).
 
+=back
+
 =cut
 
 sub count {
@@ -129,10 +141,16 @@ sub _load_children {
     return $self;
 }
 
-=item $child = $outline->first()
+=head3 first
+
+    $child = $outline->first()
+
+=over
 
 Return the first child of the current outline level, if one exists.
 
+=back
+
 =cut
 
 sub first {
@@ -144,10 +162,16 @@ sub first {
     return $self->{'First'};
 }
 
-=item $child = $outline->last()
+=head3 last
+
+    $child = $outline->last()
+
+=over
 
 Return the last child of the current outline level, if one exists.
 
+=back
+
 =cut
 
 sub last {
@@ -159,11 +183,17 @@ sub last {
     return $self->{'Last'};
 }
 
-=item $parent = $outline->parent()
+=head3 parent
+
+    $parent = $outline->parent()
+
+=over
 
 Return the parent of the current item, if not at the top level of the outline
 tree.
 
+=back
+
 =cut
 
 sub parent {
@@ -173,10 +203,16 @@ sub parent {
     return $self->{'Parent'};
 }
 
-=item $sibling = $outline->prev()
+=head3 prev
+
+    $sibling = $outline->prev()
+
+=over
 
 Return the previous item of the current level of the outline tree.
 
+=back
+
 =cut
 
 sub prev {
@@ -186,10 +222,16 @@ sub prev {
     return $self->{'Prev'};
 }
 
-=item $sibling = $outline->next()
+=head3 next
+
+    $sibling = $outline->next()
+
+=over
 
 Return the next item of the current level of the outline tree.
 
+=back
+
 =cut
 
 sub next {
@@ -199,17 +241,19 @@ sub next {
     return $self->{'Next'};
 }
 
-=back
-
 =head2 Modify the Outline Tree
 
-=over 
+=head3 outline
 
-=item $child_outline = $parent_outline->outline()
+    $child_outline = $parent_outline->outline()
+
+=over
 
 Returns a new sub-outline (nested outline) added at the end of the
 current outline's children.
 
+=back
+
 =cut
 
 sub outline {
@@ -228,10 +272,16 @@ sub outline {
     return $child;
 }
 
-=item $sibling = $outline->insert_after()
+=head3 insert_after
+
+    $sibling = $outline->insert_after()
+
+=over
 
 Add an outline item immediately following the current item.
 
+=back
+
 =cut
 
 sub insert_after {
@@ -249,10 +299,16 @@ sub insert_after {
     return $sibling;
 }
 
-=item $sibling = $outline->insert_before()
+=head3 insert_before
+
+    $sibling = $outline->insert_before()
+
+=over
 
 Add an outline item immediately preceding the current item.
 
+=back
+
 =cut
 
 sub insert_before {
@@ -284,12 +340,18 @@ sub _reset_children {
     return $self;
 }
 
-=item $outline->delete()
+=head3 delete
+
+    $outline->delete()
+
+=over
 
 Remove the current outline item from the outline tree. If the item has any
 children, they will effectively be deleted as well, since they will no longer 
 be linked.
 
+=back
+
 =cut
 
 sub delete {
@@ -307,12 +369,18 @@ sub delete {
     return;
 }
 
-=item $boolean = $outline->is_open() # Get
+=head3 is_open
 
-=item $outline = $outline->is_open($boolean) # Set
+    $boolean = $outline->is_open() # Get
+
+    $outline = $outline->is_open($boolean) # Set
+
+=over
 
 Get/set whether the outline is expanded (open) or collapsed (closed).
 
+=back
+
 =cut
 
 sub is_open {
@@ -337,12 +405,18 @@ sub is_open {
     return $self;
 }
 
-=item $outline->open()
+=head3 open
+
+    $outline->open()
+
+=over
 
 Set the status of the outline to open (i.e., expanded).
 
 This is an B<alternate> method to using is_open(true).
 
+=back
+
 =cut
 
 # deprecated in API2
@@ -352,12 +426,18 @@ sub open {
     return $self;
 }
 
-=item $outline->closed()
+=head3 closed
+
+    $outline->closed()
+
+=over
 
 Set the status of the outline to closed (i.e., collapsed).
 
 This is an B<alternate> method to using is_open(false).
 
+=back
+
 =cut
 
 # deprecated in API2
@@ -367,18 +447,20 @@ sub closed {
     return $self;
 }
 
-=back
-
 =head2 Set Outline Attributes
 
+=head3 title
+
+    $title = $outline->title() # Get
+
+    $outline = $outline->title($text) # Set
+
 =over
 
-=item $title = $outline->title() # Get
-
-=item $outline = $outline->title($text) # Set
-
 Get/set the title of the outline item.
 
+=back
+
 =cut
 
 sub title {
@@ -396,9 +478,13 @@ sub title {
     return $self;
 }
 
-=item $outline->dest($page_object, %position)
+=head3 dest
 
-=item $outline->dest($page_object)
+    $outline->dest($page_object, %position)
+
+    $outline->dest($page_object)
+
+=over
 
 Sets the destination page and optional position of the outline.
 
@@ -407,13 +493,15 @@ Sets the destination page and optional position of the outline.
 "xyz" is the B<default> fit setting, with position (left and top) and zoom
 the same as the calling page's.
 
-=item $outline->dest($name, %position)
+    $outline->dest($name, %position)
 
-=item $outline->dest($name)
+    $outline->dest($name)
 
 Connect the Outline to a "Named Destination" defined elsewhere,
 and optional positioning as described above.
 
+=back
+
 =cut
 
 sub dest {
@@ -470,13 +558,13 @@ sub _fit {
     return $self;
 }
 
-=back
-
 =head2 Destination targets
 
-=over
+=head3 uri, url
 
-=item $outline->uri($url)
+    $outline->uri($url)
+
+=over
 
 Defines the outline as launch-url with url C<$url>, typically a web page.
 
@@ -484,6 +572,8 @@ B<Alternate name:> C<url>
 
 Either C<uri> or C<url> may be used; C<uri> is for compatibility with PDF::API2.
 
+=back
+
 =cut
 
 sub url { return uri(@_); }  # alternate name
@@ -500,7 +590,11 @@ sub uri {
     return $self;
 }
 
-=item $outline->launch($file)
+=head3 launch, file
+
+    $outline->launch($file)
+
+=over
 
 Defines the outline as launch-file with filepath C<$file>. This is typically
 a local application or file.
@@ -509,6 +603,8 @@ B<Alternate name:> C<file>
 
 Either C<launch> or C<file> may be used; C<launch> is for compatibility with PDF::API2.
 
+=back
+
 =cut
 
 sub file { return launch(@_); } # alternate name
@@ -525,9 +621,13 @@ sub launch {
     return $self;
 }
 
-=item $outline->pdf($pdffile, $page_number, %position, %args)
+=head3 pdf, pdf_file, pdfile
 
-=item $outline->pdf($pdffile, $page_number)
+    $outline->pdf($pdffile, $page_number, %position, %args)
+
+    $outline->pdf($pdffile, $page_number)
+
+=over
 
 Defines the destination of the outline as a PDF-file with filepath 
 C<$pdffile>, on page C<$pagenum> (default 0), and position C<%position> 
@@ -538,6 +638,8 @@ B<Alternate names:> C<pdf_file> and C<pdfile>
 Either C<pdf> or C<pdf_file> (or the older C<pdfile>) may be used; C<pdf> is 
 for compatibility with PDF::API2. 
 
+=back
+
 =cut
 
 sub pdf_file { return pdf(@_); } # alternative method
@@ -591,8 +693,4 @@ sub outobjdeep {
     return $self->SUPER::outobjdeep(@_);
 }
 
-=back
-
-=cut
-
 1;
