@@ -5,8 +5,8 @@ use base 'PDF::Builder::Basic::PDF::Dict';
 use strict;
 use warnings;
 
-our $VERSION = '3.025'; # VERSION
-our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
 
 use PDF::Builder::Util qw(pdfkey);
 use PDF::Builder::Basic::PDF::Utils; # PDFName
@@ -19,12 +19,16 @@ PDF::Builder::Resource - Base class for PDF resources. Inherit from L<PDF::Build
 
 =head1 METHODS
 
+=head2 new
+
+    $resource = PDF::Builder::Resource->new($pdf, $name)
+
 =over
 
-=item $resource = PDF::Builder::Resource->new($pdf, $name)
-
 Returns a resource object.
 
+=back
+
 =cut
 
 sub new {
@@ -47,12 +51,18 @@ sub new {
 # Note: new_api() removed in favor of new():
 #   new_api($api, ...)  replace with new($api->{'pdf'}, ...)
 
-=item $name = $resource->name() # Get
+=head2 name
 
-=item $resource->name($name) # Set
+    $name = $resource->name() # Get
+
+    $resource->name($name) # Set
+
+=over
 
 Get or set the name of the resource.
 
+=back
+
 =cut
 
 sub name {
@@ -71,8 +81,4 @@ sub name {
 #    return $self->SUPER::outobjdeep($fh, $pdf, %options);
 #}
 
-=back
-
-=cut
-
 1;
