@@ -5,8 +5,8 @@ use base 'PDF::Builder::Resource::CIDFont';
 use strict;
 use warnings;
 
-our $VERSION = '3.025'; # VERSION
-our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
 
 use PDF::Builder::Basic::PDF::Utils;
 use PDF::Builder::Resource::CIDFont::TrueType::FontFile;
@@ -18,9 +18,11 @@ PDF::Builder::Resource::CIDFont::TrueType - TrueType font support
 
 =head1 METHODS
 
-=over
+=head2 new
 
-=item $font = PDF::Builder::Resource::CIDFont::TrueType->new($pdf, $file, %options)
+    $font = PDF::Builder::Resource::CIDFont::TrueType->new($pdf, $file, %options)
+
+=over
 
 Returns a font object.
 
@@ -31,6 +33,8 @@ Defined Options:
     nosubset ... disables subsetting. Any value causes the full font to be
                  embedded, rather than only the glyphs needed.
 
+=back
+
 =cut
 
 sub new {
@@ -82,14 +86,50 @@ sub new {
     return $self;
 }
 
+=head2 fontfile
+
+    $font->fontfile()
+
+=over
+
+Returns font file object (' ff' element), so its methods may be invoked.
+
+=back
+
+=cut
+
 sub fontfile { 
     return $_[0]->{' ff'};
 }
 
+=head2 fontobj
+
+    $font->fontobj()
+
+=over
+
+Returns font object, so its methods and properties may be used.
+
+=back
+
+=cut
+
 sub fontobj {
     return $_[0]->data()->{'obj'};
 }
 
+=head2 wxByCId
+
+    $font->wxByCId($gID)
+
+=over
+
+Returns unscaled glyph width, given the glyph ID (CID).
+
+=back
+
+=cut
+
 sub wxByCId {
     my ($self, $g) = @_;
 
@@ -105,18 +145,57 @@ sub wxByCId {
     return $w;
 }
 
+=head2 haveKernPairs
+
+    $flag = $font->haveKernPairs()
+
+=over
+
+Does the font include kerning data? Invokes fontfile's haveKernPairs().
+Not clear what additional optional arguments are.
+
+=back
+
+=cut
+
 sub haveKernPairs {
     my $self = shift;
 
     return $self->fontfile()->haveKernPairs(@_);
 }
 
+=head2 kernPairCid
+
+    $flag = $font->kernPairCid($gID, $n)
+
+=over
+
+Returns kerning information for? Not clear what additional arguments are.
+Invokes fontfile's kernPairCid() method.
+
+=back
+
+=cut
+
 sub kernPairCid {
     my $self = shift;
 
     return $self->fontfile()->kernPairCid(@_);
 }
 
+=head2 subsetByCid
+
+    $font->subsetByCid($gID)
+
+=over
+
+Invokes subsetByCId() method from fontfile() to put the glyph into the embedded
+font cache in the PDF.
+
+=back
+
+=cut
+
 sub subsetByCId {
     my $self = shift;
 
@@ -125,6 +204,18 @@ sub subsetByCId {
     return $self->fontfile()->subsetByCId($g);
 }
 
+=head2 subvec
+
+    $font->subvec($gID)
+
+=over
+
+(No Information) invokes fontfile's subvec() method.
+
+=back
+
+=cut
+
 sub subvec {
     my $self = shift;
 
@@ -133,10 +224,34 @@ sub subvec {
     return $self->fontfile()->subvec($g);
 }
 
+=head2 glyphNum
+
+    $count = $font->glyphNum()
+
+=over
+
+Number of glyphs in the font.
+
+=back
+
+=cut
+
 sub glyphNum {
     return $_[0]->fontfile()->glyphNum();
 }
 
+=head2 outobjdeep
+
+    $font->outobjdeep()
+
+=over
+
+(No Information) output to PDF
+
+=back
+
+=cut
+
 sub outobjdeep {
     my ($self, $fh, $pdf) = @_;
 
@@ -176,8 +291,4 @@ sub outobjdeep {
     return $self->SUPER::outobjdeep($fh, $pdf);
 }
 
-=back
-
-=cut
-
 1;
