@@ -3,8 +3,8 @@ package PDF::Builder::Resource::Font::CoreFont::trebuchetbold;
 use strict;
 use warnings;
 
-our $VERSION = '3.021'; # VERSION
-my $LAST_UPDATE = '3.018'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.018'; # manually update whenever code is changed
 
 =head1 NAME
 
